yocto.lists.yoctoproject.org archive mirror
 help / color / mirror / Atom feed
From: Steve Sakoman <steve@sakoman.com>
To: yocto@lists.yoctoproject.org
Subject: [yocto-autobuilder2] schedulers: update to add mickledore
Date: Tue, 23 May 2023 08:38:00 -1000	[thread overview]
Message-ID: <f57cb8e05ff01c2bd2718b684198eeedd56a7737.1684866967.git.steve@sakoman.com> (raw)
In-Reply-To: <cover.1684866967.git.steve@sakoman.com>

Signed-off-by: Steve Sakoman <steve@sakoman.com>
---
 schedulers.py | 25 ++++++++++++++++++++-----
 1 file changed, 20 insertions(+), 5 deletions(-)

diff --git a/schedulers.py b/schedulers.py
index 24cbd70..2f7a8ab 100644
--- a/schedulers.py
+++ b/schedulers.py
@@ -60,6 +60,21 @@ branchdefaults = {
         'branch_meta-openembedded': 'master',
         'branch_oecore': 'master',
     },
+    'mickledore': {
+        'branch': 'mickledore',
+        'branch_poky': 'mickledore',
+        'branch_bitbake': '2.4',
+        'branch_meta-arm': 'mickledore',
+        'branch_meta-agl': 'next',
+        'branch_meta-aws': 'mickledore',
+        'branch_meta-gplv2': 'master',
+        'branch_meta-intel': 'mickledore',
+        'branch_meta-mingw': 'master',
+        'branch_meta-openembedded': 'mickledore',
+        'branch_meta-ti': 'master',
+        'branch_meta-virtualization': 'mickledore',
+        'branch_oecore': 'mickledore',
+    },
     'langdale': {
         'branch': 'langdale',
         'branch_poky': 'langdale',
@@ -377,7 +392,7 @@ def parent_scheduler(target):
             name="branchselector",
             default="master",
             label="Release Shortcut Selector",
-            choices=["master", "master-next", "abelloni-next", "mut", "langdale", "kirkstone", "honister", "hardknott", "gatesgarth", "dunfell", "zeus", "warrior", "thud", "sumo", "rocko", "pyro", "morty"],
+            choices=["master", "master-next", "abelloni-next", "mut", "mickledore", "langdale", "kirkstone", "honister", "hardknott", "gatesgarth", "dunfell", "zeus", "warrior", "thud", "sumo", "rocko", "pyro", "morty"],
             selectors=branchdefaults),
         util.BooleanParameter(
             name="swat_monitor",
@@ -443,9 +458,9 @@ schedulers.append(sched.Nightly(name='nightly-check-layer', branch='master', pro
 schedulers.append(sched.Nightly(name='nightly-metrics', branch='master', properties=parent_default_props('metrics'),
                   builderNames=['metrics'], hour=7, minute=0))
 
-# Run check-layer-nightly twice a week for langdale
-schedulers.append(sched.Nightly(name='nightly-check-layer-langdale', properties=parent_default_props('check-layer-nightly', 'langdale'),
-                  builderNames=['check-layer-nightly'], dayOfWeek=[2, 5], hour=2, minute=0, codebases = {'' : {'branch' : 'langdale'}}))
+# Run check-layer-nightly twice a week for mickledore
+schedulers.append(sched.Nightly(name='nightly-check-layer-mickledore', properties=parent_default_props('check-layer-nightly', 'mickledore'),
+                  builderNames=['check-layer-nightly'], dayOfWeek=[2, 5], hour=2, minute=0, codebases = {'' : {'branch' : 'mickledore'}}))
 
 # Run check-layer-nightly twice a week for kirkstone
 schedulers.append(sched.Nightly(name='nightly-check-layer-kirkstone', properties=parent_default_props('check-layer-nightly', 'kirkstone'),
@@ -467,7 +482,7 @@ schedulers.append(sched.Nightly(name='nightly-auh', branch='master', properties=
 
 # If any of our sphinx docs branches change, trigger a build
 schedulers.append(sched.AnyBranchScheduler(name="yocto-docs-changed",
-            change_filter=util.ChangeFilter(project=["yocto-docs"], branch=[None, "master", "master-next", "langdale", "kirkstone", "honister", "hardknott", "gatesgarth", "dunfell", "transition"]),
+            change_filter=util.ChangeFilter(project=["yocto-docs"], branch=[None, "master", "master-next", "mickledore", "langdale", "kirkstone", "honister", "hardknott", "gatesgarth", "dunfell", "transition"]),
             codebases = ['', 'yocto-docs', 'bitbake'],
             treeStableTimer=60,
             builderNames=["docs"]))
-- 
2.34.1



           reply	other threads:[~2023-05-23 18:38 UTC|newest]

Thread overview: expand[flat|nested]  mbox.gz  Atom feed
 [parent not found: <cover.1684866967.git.steve@sakoman.com>]

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=f57cb8e05ff01c2bd2718b684198eeedd56a7737.1684866967.git.steve@sakoman.com \
    --to=steve@sakoman.com \
    --cc=yocto@lists.yoctoproject.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).